import styled from 'styled-components';
import { motion } from 'framer-motion';
import theme from '../../../../theme';

export interface DivierProps {
  length?: number;
  thickness?: number;
  color?: string;
  direction?: 'vertical' | 'horizontal';
  margin?: string;
  isFullWidth?: boolean;
}

export default function Divider(props: DivierProps) {
  return <DividerStyled {...props} />;
}

Divider.defaultProps = {
  thickness: 1,
  color: theme.colors.black,
  direction: 'horizontal',
  length: 500,
  isFullWidth: false,
};

const DividerStyled = styled(motion.div)<DivierProps>`
  width: ${({ direction, thickness, length, isFullWidth }) => (isFullWidth ? '100%' : direction === 'vertical' ? thickness : length)}px;
  height: ${({ direction, thickness, length }) => (direction === 'vertical' ? length : thickness)}px;
  background: ${({ color }) => color};
  margin: ${props => props.margin};
`;
