import { ReactNode, useState } from 'react';
import styled from 'styled-components';
import { motion, Variants } from 'framer-motion';

export interface ToggleProps {
  width;
  toggle?: any;
  buttonState?: boolean;
}

function Toggle({}: ToggleProps) {
  const [buttonState, setButtonState] = useState(false);

  const buttonVariants: Variants = {
    on: {
      right: 4,
      transition: {
        spring: 'tween',
        duration: 0.25,
      },
    },
    off: {
      transition: {
        spring: 'tween',
        duration: 0.25,
      },
    },
  };

  const bgVariants = {
    on: { background: 'lime' },
    off: { background: 'lightgray' },
  };

  return (
    <Box center width={120} height={68} borderRadius={60} background={'#999'} onTap={() => setButtonState(prev => !prev)} variants={bgVariants} animate={buttonState ? 'on' : 'off'}>
      <Switch center={'y'} x={4} size={60} borderRadius={30} background={'white'} shadow={'0 0 10px rgba(0, 0, 0, .25)'} variants={buttonVariants} animate={buttonState ? 'on' : 'off'} />
    </Box>
  );
}

export default Toggle;

const Box = styled(motion.div)<any>`
  width: ${props => props.width}px;
  height: ${props => props.height}px;
  border-radius: ${props => props.borderRadius}px;
  background-color: ${props => props.background};
  overflow: hidden;
  position: relative;
  padding: 4px;
`;
const Switch = styled(motion.div)<any>`
  width: ${props => props.size}px;
  height: ${props => props.size}px;
  background: white;
  border-radius: 30px;
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.25);
  position: absolute;
`;
