import styled from 'styled-components';
import { motion } from 'framer-motion';
import { produce } from 'immer';
import theme from '../../../../theme';
import Paragraph, { ParagraphProps } from '../../atoms/Paragraph/Paragraph';
import Title, { TitleProps } from '../../atoms/Title/Title';
import Button, { ButtonProps } from '../../molecules/Button/Button';

export interface Feature2Props {
  thumbnail?: string;
  titleProps?: TitleProps;
  descriptionProps?: ParagraphProps;
  isMobile?: boolean;
  backgroundColor?: string;
  buttonProps?: ButtonProps;
  imageBorderRadius?: number;
}

export default function Feature2(props: Feature2Props) {
  const { backgroundColor, thumbnail, titleProps, descriptionProps, buttonProps, imageBorderRadius, isMobile } = props;

  return (
    <Box backgroundColor={backgroundColor} isMobile={isMobile}>
      <Thumbnail isMobile={isMobile} src={thumbnail} borderRadius={imageBorderRadius} />
      <Title margin={'12px 0 0'} {...titleProps} isMobile={isMobile} />
      <Paragraph margin="12px 0 0" {...descriptionProps} isMobile={isMobile} />
    </Box>
  );
}

Feature2.defaultProps = {
  thumbnail: 'https://picsum.photos/id/89/1800/800',
  titleProps: produce(Title.defaultProps, draft => {
    draft.fontWeight = 'bold';
    draft.size = 'sm';
    draft.color = theme.colors.black;
    draft.content = 'Title 01 타이틀 01\nTitle 02 타이틀 02';
  }),
  descriptionProps: produce(Title.defaultProps, draft => {
    draft.fontWeight = 'normal';
    draft.size = 'md';
    draft.color = theme.colors.gray400;
    draft.content = '기능을 설명하는 글입니다.기능을 설명하는 글입니다.기능을 설명하는 글입니다.';
  }),
  isMobile: false,
  backgroundColor: 'transparent',
  buttonProps: produce(Button.defaultProps, draft => {
    draft.backgroundColor = theme.colors.white;
    draft.icon = 'chevron-right';
    draft.iconPosition = 'right';
    draft.color = theme.colors.gray500;
    draft.content = '포트폴리오 보러가기';
    draft.border.color = theme.colors.gray500;
    draft.border.width = 1;
  }),
  imageBorderRadius: 16,
};

const Box = styled(motion.div)<any>`
  display: flex;
  flex-direction: column;
  background-color: ${props => props.backgroundColor};
  width: 100%;
  margin: 0 auto;
  border-radius: 20px;
`;
const Thumbnail = styled(motion.img)<any>`
  width: 100%;
  border-radius: ${props => props.imageBorderRadius}px;
  border-radius: 16px;
`;
